@@ -44,12 +44,9 @@ def compare_versions(plain_output: bool) -> int:
 	# We wrap this whole thing in a try block, because we need to call
 	# driver.quit() if execution is interrupted (like by ctrl + c, or by an unhandled exception). If we don't call driver.quit(),
 	# Firefox will stay around as a zombie process even if the Python script is dead.
+	driver = None
 	try:
-		try:
-			driver = se.browser.initialize_selenium_firefox_webdriver()
-		except se.MissingDependencyException as ex:
-			se.print_error(ex, plain_output=plain_output)
-			return ex.code
+		driver = se.browser.initialize_selenium_firefox_webdriver()
 
 		# Ready to go!
 		for target in args.targets:
@@ -187,12 +184,19 @@ def compare_versions(plain_output: bool) -> int:
 
 						with open(output_directory / "diff.html", "w", encoding="utf-8") as file:
 							file.write(html)
+
+	except se.MissingDependencyException as ex:
+		se.print_error(ex, plain_output=plain_output)
+		return ex.code
+
 	except KeyboardInterrupt as ex:
 		# Bubble the exception up, but proceed to `finally` so we quit the driver
 		raise ex
+
 	finally:
 		try:
-			driver.quit()
+			if driver:
+				driver.quit()
 		except Exception:
 			# We might get here if we ctrl + c before selenium has finished initializing the driver
 			pass
