@@ -128,13 +128,6 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"<abbr>etc\.</abbr>([”’]?(?:</p>|\s+[“‘]?[\p{Uppercase_Letter}]))", r"""<abbr class="eoc">etc.</abbr>\1""", xhtml)
 	xhtml = regex.sub(r"""<abbr( epub:type="[^"]+")?>([^<]+\.)</abbr>([”’]?</p>)""", r"""<abbr class="eoc"\1>\2</abbr>\3""", xhtml)
 
-	# We may have added eoc classes twice, so remove duplicates here
-	xhtml = regex.sub(r"""<abbr class="(.*) eoc(\s+eoc)+">""", r"""<abbr class="\1 eoc">""", xhtml)
-
-	# Clean up nesting errors
-	xhtml = regex.sub(r"""<abbr class="eoc"><abbr>([^<]+)</abbr></abbr>""", r"""<abbr class="eoc">\1</abbr>""", xhtml)
-	xhtml = regex.sub(r"""class="eoc eoc""", r"""class="eoc""", xhtml)
-
 	# Get Roman numerals >= 2 characters
 	# We only wrap these if they're standalone (i.e. not already wrapped in a tag) to prevent recursion in multiple runs
 	# Ignore "numerals" followed by a dash, as they are more likely something like `x-ray` or `v-shaped`
@@ -166,12 +159,25 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"([0-9]+)\s*m\.?p\.?h\.?", fr"\1{se.NO_BREAK_SPACE}<abbr>mph</abbr>", xhtml, flags=regex.IGNORECASE)
 	xhtml = regex.sub(r"([0-9]+)\s*h\.?p\.?", fr"\1{se.NO_BREAK_SPACE}<abbr>hp</abbr>", xhtml, flags=regex.IGNORECASE)
 
-	# We may have added HTML tags within title tags. Remove those here
-	matches = regex.findall(r"<title>.+?</title>", xhtml)
-	if matches:
-		xhtml = regex.sub(r"<title>.+?</title>", f"<title>{se.formatting.remove_tags(matches[0])}</title>", xhtml)
+	dom = se.easy_xml.EasyXmlTree(xhtml)
 
-	return xhtml
+	# We may have added HTML tags within title tags. Remove those here.
+	for node in dom.xpath("/html/head/title"):
+		replacement_node = se.easy_xml.EasyXmlElement(f"<title>{node.inner_text()}</title>")
+		node.replace_with(replacement_node)
+
+	# We may have added `eoc` classes twice, so remove duplicates here
+	for node in dom.xpath("/html/body//*[re:test(@class, '\\beoc\\seoc\\b')]"):
+		node.set_attr("class", regex.sub(r"\beoc\seoc\b", "eoc", node.get_attr("class")))
+
+	# Clean up nesting errors
+	for node in dom.xpath("/html/body//abbr/abbr"):
+		node.unwrap()
+
+	for node in dom.xpath("/html/body//blockquote//*[name() = 'header' or name() = 'footer']"):
+		node.set_attr("role", "presentation")
+
+	return dom.to_string()
 
 def get_flesch_reading_ease(xhtml: str) -> float:
 	"""
@@ -1539,13 +1545,14 @@ def _get_flattened_children(node: EasyXmlElement, allow_header: bool) -> List[Ea
 
 	return result
 
-def find_unexpected_ids(dom: EasyXmlTree) -> List[Tuple[EasyXmlElement, str]]:
+def find_unexpected_ids(dom: EasyXmlTree, no_endnotes: bool = False) -> List[Tuple[EasyXmlElement, str]]:
 	"""
 	Given a DOM tree, return a list of tuples containing nodes and their expected ID attributes.
 	Only nodes with unexpected IDs are returned.
 
 	INPUTS
 	dom: An EasyXmlTree
+	no_endnotes: A boolean indicating whether endnotes are examined; by default they are
 
 	OUTPUTS
 	A list of tuples of (node, expected_id)
@@ -1558,6 +1565,11 @@ def find_unexpected_ids(dom: EasyXmlTree) -> List[Tuple[EasyXmlElement, str]]:
 	for node in dom_copy.xpath("/html/body//*[contains(@epub:type, 'noteref')]"):
 		node.remove()
 
+	# The build-ids command has an option to exclude endnotes; if true, then remove endnotes as well
+	if no_endnotes:
+		for node in dom_copy.xpath("/html/body//*[contains(@epub:type, 'endnote')]"):
+			node.remove()
+
 	# IDs are set to `{closest_parent_sectioning_element_id}-{tag_name}-{n}`.
 	# Lines of poetry are set to `{closest_poem_sectioning_element_id}-line-{n}`.
 	# Notes:
